@@ -237,6 +237,13 @@ class InstallImageBuilder:
         )
         bootloader_config.write()
 
+        if self.firmware.efi_mode():
+            efi_loader = Temporary(
+                prefix='efi-loader.', path=self.target_dir
+            ).new_file()
+            bootloader_config._create_embedded_fat_efi_image(efi_loader.name)
+            self.custom_iso_args['meta_data']['efi_loader'] = efi_loader.name
+
         # create initrd for install image
         log.info('Creating install image boot image')
         self._create_iso_install_kernel_and_initrd()
@@ -363,7 +370,7 @@ class InstallImageBuilder:
 
     def _create_pxe_install_kernel_and_initrd(self) -> None:
         kernelname = 'pxeboot.{0}.kernel'.format(self.pxename)
-        initrdname = 'pxeboot.{0}.initrd.xz'.format(self.pxename)
+        initrdname = 'pxeboot.{0}.initrd'.format(self.pxename)
         kernel = Kernel(self.boot_image_task.boot_root_directory)
         if kernel.get_kernel():
             kernel.copy_kernel(self.pxe_dir.name, kernelname)
