@@ -17,7 +17,9 @@
 #
 import re
 import logging
-from typing import List
+from typing import (
+    List, Dict
+)
 
 # project
 from kiwi.command import command_call_type
@@ -97,6 +99,17 @@ class PackageManagerPacman(PackageManagerBase):
         """
         self.exclude_requests.append(name)
 
+    def setup_repository_modules(
+        self, collection_modules: Dict[str, List[str]]
+    ) -> None:
+        """
+        Repository modules not supported for pacman.
+        The method does nothing in this scope
+
+        :param dict collection_modules: unused
+        """
+        pass
+
     def process_install_requests_bootstrap(
         self, root_bind: RootBind = None
     ) -> command_call_type:
