@@ -18,12 +18,17 @@
 import os
 import logging
 from collections import namedtuple
+from textwrap import dedent
 
 # project
 from kiwi.firmware import FirmWare
 from kiwi.system.size import SystemSize
 from kiwi.defaults import Defaults
 from kiwi.xml_state import XMLState
+from kiwi.exceptions import (
+    KiwiVolumeTooSmallError,
+    KiwiPartitionTooSmallError
+)
 
 log = logging.getLogger('kiwi')
 
@@ -53,6 +58,7 @@ class DiskSetup:
         self.bootloader = xml_state.get_build_type_bootloader_name()
         self.oemconfig = xml_state.get_build_type_oemconfig_section()
         self.volumes = xml_state.get_volumes()
+        self.custom_partitions = xml_state.get_partitions()
 
         self.firmware = FirmWare(
             xml_state
@@ -82,6 +88,13 @@ class DiskSetup:
             '--> system data with filesystem overhead needs %s MB',
             root_filesystem_mbytes
         )
+        if self.custom_partitions:
+            partition_mbytes = self._accumulate_partitions_size()
+            if partition_mbytes:
+                calculated_disk_mbytes += partition_mbytes
+                log.info(
+                    '--> partition(s) size setup adding %s MB', partition_mbytes
+                )
         if self.volume_manager and self.volume_manager == 'lvm':
             lvm_overhead_mbytes = Defaults.get_lvm_overhead_mbytes()
             log.info(
@@ -265,6 +278,35 @@ class DiskSetup:
             if recovery_mbytes:
                 return int(recovery_mbytes[0] * 1.7)
 
+    def _accumulate_partitions_size(self):
+        """
+        Calculate number of mbytes to add to the disk to allow
+        the creaton of the partitions with their configured size
+        """
+        disk_partition_mbytes = 0
+        data_partition_mbytes = self._calculate_partition_mbytes()
+        for map_name in sorted(self.custom_partitions.keys()):
+            partition_mount_path = self.custom_partitions[map_name].mountpoint
+            partition_mbsize = self.custom_partitions[map_name].mbsize
+            disk_add_mbytes = int(partition_mbsize) - \
+                data_partition_mbytes.partition[partition_mount_path]
+            if disk_add_mbytes > 0:
+                disk_partition_mbytes += disk_add_mbytes
+            else:
+                message = dedent('''\n
+                    Requested partition size {0}MB for {1!r} is too small
+
+                    The minimum byte value to store the data below
+                    the {1!r} path was calculated to be {2}MB
+                ''')
+                raise KiwiPartitionTooSmallError(
+                    message.format(
+                        partition_mbsize, partition_mount_path,
+                        data_partition_mbytes.partition[partition_mount_path]
+                    )
+                )
+        return disk_partition_mbytes
+
     def _accumulate_volume_size(self, root_mbytes):
         """
         Calculate number of mbytes to add to the disk to allow
@@ -283,9 +325,9 @@ class DiskSetup:
                 disk_volume_mbytes += Defaults.get_min_volume_mbytes()
             return disk_volume_mbytes
 
-        # For vmx types we need to add the configured volume
-        # sizes because the image is used directly as it is without
-        # being deployed and resized on a target disk
+        # For static disk(no resize requested) we need to add the
+        # configured volume sizes because the image is used directly
+        # as it is without being deployed and resized on a target disk
         for volume in self.volumes:
             if volume.realpath and not volume.realpath == '/' and volume.size:
                 [size_type, req_size] = volume.size.split(':')
@@ -299,9 +341,17 @@ class DiskSetup:
                     disk_volume_mbytes += disk_add_mbytes + \
                         Defaults.get_min_volume_mbytes()
                 else:
-                    log.warning(
-                        'volume size of %s MB for %s is too small, skipped',
-                        int(req_size), volume.realpath
+                    message = dedent('''\n
+                        Requested volume size {0}MB for {1!r} is too small
+
+                        The minimum byte value to store the data below
+                        the {1!r} path was calculated to be {2}MB
+                    ''')
+                    raise KiwiVolumeTooSmallError(
+                        message.format(
+                            req_size, volume.realpath,
+                            data_volume_mbytes.volume[volume.realpath]
+                        )
                     )
 
         if root_volume:
@@ -367,3 +417,29 @@ class DiskSetup:
             volume=volume_mbytes,
             total=volume_total
         )
+
+    def _calculate_partition_mbytes(self):
+        """
+        Calculate the number of mbytes each partition path consumes
+        """
+        partition_mbytes_type = namedtuple(
+            'partition_mbytes_type', ['partition']
+        )
+        partition_mbytes = {}
+        for map_name in sorted(self.custom_partitions.keys()):
+            partition_mount_path = self.custom_partitions[map_name].mountpoint
+            partition_filesystem = self.custom_partitions[map_name].filesystem
+            path_to_partition = os.path.normpath(
+                os.sep.join([self.root_dir, partition_mount_path])
+            )
+            if os.path.exists(path_to_partition):
+                partition_size = SystemSize(path_to_partition)
+                partition_mbytes[partition_mount_path] = partition_size.customize(
+                    partition_size.accumulate_mbyte_file_sizes(),
+                    partition_filesystem
+                )
+            else:
+                partition_mbytes[partition_mount_path] = 0
+        return partition_mbytes_type(
+            partition=partition_mbytes
+        )
