@@ -334,6 +334,8 @@ class Profile:
             type_section.get_vga()
         self.dot_profile['kiwi_startsector'] = \
             self.xml_state.get_disk_start_sector()
+        self.dot_profile['kiwi_luks_empty_passphrase'] = \
+            True if type_section.get_luks() == '' else False
 
     def _profile_names_to_profile(self):
         # kiwi_profiles
