@@ -11,7 +11,7 @@ from kiwi.exceptions import KiwiCommandCapabilitiesError
 
 class TestArchiveTar:
     @patch('kiwi.archive.tar.Command.run')
-    def setup(self, mock_command):
+    def setup(self, mock_ArchiveTar, mock_command):
         command = mock.Mock()
         command.output = 'version 1.27.0'
         mock_command.return_value = command
