@@ -7,7 +7,7 @@ from kiwi.filesystem.ext4 import FileSystemExt4
 
 class TestFileSystemExt4:
     @patch('os.path.exists')
-    def setup(self, mock_exists):
+    def setup(self, mock_FileSystemExt4, mock_exists):
         mock_exists.return_value = True
         provider = mock.Mock()
         provider.get_device = mock.Mock(
