@@ -10,7 +10,7 @@ from kiwi.exceptions import KiwiMappedDeviceError
 
 class TestMappedDevice:
     @patch('os.path.exists')
-    def setup(self, mock_path):
+    def setup(self, mock_MappedDevice, mock_path):
         mock_path.return_value = True
         self.device_provider = Mock()
         self.device_provider.is_loop = Mock()
