@@ -1,23 +1,29 @@
 from mock import patch
 
-import mock
+from mock import Mock
+import kiwi
 
+from kiwi.defaults import Defaults
 from kiwi.storage.subformat.vdi import DiskFormatVdi
 
 
 class TestDiskFormatVdi:
-    @patch('platform.machine')
-    def setup(self, mock_machine):
-        mock_machine.return_value = 'x86_64'
-        xml_data = mock.Mock()
-        xml_data.get_name = mock.Mock(
+    def setup(self):
+        Defaults.set_platform_name('x86_64')
+        xml_data = Mock()
+        xml_data.get_name = Mock(
             return_value='some-disk-image'
         )
-        self.xml_state = mock.Mock()
+        self.xml_state = Mock()
         self.xml_state.xml_data = xml_data
-        self.xml_state.get_image_version = mock.Mock(
+        self.xml_state.get_image_version = Mock(
             return_value='1.2.3'
         )
+        self.runtime_config = Mock()
+        self.runtime_config.get_bundle_compression.return_value = False
+        kiwi.storage.subformat.base.RuntimeConfig = Mock(
+            return_value=self.runtime_config
+        )
         self.disk_format = DiskFormatVdi(
             self.xml_state, 'root_dir', 'target_dir'
         )
