@@ -7,6 +7,13 @@ class TestBlockID:
     def setup(self):
         self.blkid = BlockID('device')
 
+    @patch('kiwi.utils.block.Command.run')
+    def test_setup_with_uuid_format(self, mock_command):
+        BlockID('UUID=uuid')
+        mock_command.assert_called_once_with(
+            ['blkid', '--uuid', 'uuid']
+        )
+
     @patch('kiwi.utils.block.Command.run')
     def test_get_blkid(self, mock_command):
         self.blkid.get_blkid('LABEL')
