@@ -13,8 +13,11 @@ class TestFstab(object):
     def inject_fixtures(self, caplog):
         self._caplog = caplog
 
-    def setup(self):
+    def setup(self, mock_Fstab):
         self.fstab = Fstab()
+        self.fstab.read('../data/fstab')
+
+    def test_read(self):
         with self._caplog.at_level(logging.WARNING):
             self.fstab.read('../data/fstab')
             assert format(
