@@ -35,7 +35,7 @@ class TestDataOutput:
 
     @patch('sys.stdout')
     @patch('os.system')
-    @patch('kiwi.utils.output.NamedTemporaryFile')
+    @patch('kiwi.utils.output.Temporary.new_file')
     def test_display_color(self, mock_temp, mock_system, mock_stdout):
         out_file = mock.Mock()
         out_file.name = 'tmpfile'
